

/**************************************************************/

/* Magnitude Routine                                          */

/* Description: Takes an input vectors and converts from a    */

/* 16 bit twos-complement representation to an IEEE floating  */

/* point number (32 bit)                                      */

/**************************************************************/





#define ACCURACY   4  /* 1=30%, 2=7.6%, 3=2%, 4=.5%, 5=.12%,6=.03%,

                         7=.00075%, 8=.00019% */



zsp325()

{

/#

   SUBROUTINE MAG_8(zr325ref input,zr325ref output)

   {

          

      LDR #0x50f200 => $MODE;

      LDR input => $A;

      LDR output => $B;/* get the output pointer */

      LD_C:(8) $A => $C0;  /* get the first segment */

      MAG_C:(8,ACCURACY) $C0  ;  /* convert the segment in memory */

      ST_R:(8) $R0 => $B; /* store the first segment */

   }

   SUBROUTINE MAG_16(zr325ref input,zr325ref output)

   {

          

      LDR #0x50f200 => $MODE;

      LDR input => $A;

      LDR output => $B;/* get the output pointer */

      LD_C:(16) $A => $C0;  /* get the first segment */

      MAG_C:(16,ACCURACY) $C0  ;  /* convert the segment in memory */

      ST_R:(16) $R0 => $B; /* store the first segment */

   }

   SUBROUTINE MAG_32(zr325ref input,zr325ref output)

   {

          

      LDR #0x50f200 => $MODE;

      LDR input => $A;

      LDR output => $B;/* get the output pointer */

      LD_C:(32) $A => $C0;  /* get the first segment */

      MAG_C:(32,ACCURACY) $C0  ;  /* convert the segment in memory */

      ST_R:(32) $R0 => $B; /* store the first segment */

   }

   SUBROUTINE MAG_64(zr325ref input,zr325ref output)

   {

          

      LDR #0x50f200 => $MODE;

      LDR input => $A;

      LDR output => $B;/* get the output pointer */

      ADDR #-64,[$A,$B]; /* offset the registers to use pre_increment addr */

      LD_C:(32) $A+=64 => $C0;  /* get the first segment */

      MAG_C:(32,ACCURACY) $C0  ;  /* convert the segment in memory */

      LD_C:(32) $A+=64 => $C1; /* get next segment */

      MAG_C:(32,ACCURACY) $C1 ;  /* convert the segment in memory */

      ST_R:(32) $R0 => $B+=64; /* store the first segment */

      ST_R:(32) $R1 => $B+=32; /* store the second segment */

   }

   SUBROUTINE MAG_128(zr325ref input,zr325ref output)

   {

          

      LDR #0x50f200 => $MODE;

      LDR input => $A;

      LDR output => $B;/* get the output pointer */

      ADDR #-64,[$A,$B]; /* offset the registers to use pre_increment addr */

      LD_C:(32) $A+=64 => $C0;  /* get the first segment */

      MAG_C:(32,ACCURACY) $C0  ;  /* convert the segment in memory */

      LD_C:(32) $A+=64 => $C1; /* get next segment */

      MAG_C:(32,ACCURACY) $C1 ;  /* convert the segment in memory */

      ST_R:(32) $R0 => $B+=64; /* store the first segment */

      ST_R:(32) $R1 => $B+=32; /* store the second segment */

      LD_C:(32) $A+=64 => $C0;  /* get the third segment */

      MAG_C:(32,ACCURACY) $C0  ;  /* convert the segment in memory */

      LD_C:(32) $A+=64 => $C1; /* get fourth segment */

      MAG_C:(32,ACCURACY) $C1 ;  /* convert the segment in memory */

      ST_R:(32) $R0 => $B+=32; /* store the third segment */

      ST_R:(32) $R1 => $B+=32; /* store the fourth segment */

   }

   SUBROUTINE MAG_256(zr325ref input,zr325ref output)

   {

          

      LDR #0x50f200 => $MODE;

      LDR input => $A;

      LDR output => $B;/* get the output pointer */

      ADDR #-64,[$A]; /* offset the registers to use pre_increment addr */

      ADDR #-32,[$B]; /* offset the registers to use pre_increment addr */

      LDR #2 => $LC;  /* loop twice */

MAG_LOOP_256::

      LD_C:(32) $A+=64 => $C0;  /* get the first segment */

      MAG_C:(32,ACCURACY) $C0  ;  /* convert the segment in memory */

      LD_C:(32) $A+=64 => $C1; /* get next segment */

      MAG_C:(32,ACCURACY) $C1 ;  /* convert the segment in memory */

      ST_R:(32) $R0 => $B+=32; /* store the first segment */

      ST_R:(32) $R1 => $B+=32; /* store the second segment */

      LD_C:(32) $A+=64 => $C0;  /* get the third segment */

      MAG_C:(32,ACCURACY) $C0  ;  /* convert the segment in memory */

      LD_C:(32) $A+=64 => $C1; /* get fourth segment */

      MAG_C:(32,ACCURACY) $C1 ;  /* convert the segment in memory */

      ST_R:(32) $R0 => $B+=32; /* store the third segment */

      ST_R:(32) $R1 => $B+=32; /* store the fourth segment */

      JMPC:[DL] [!LZ], MAG_LOOP_256;

   }

   SUBROUTINE MAG_512(zr325ref input,zr325ref output)

   {

          

      LDR #0x50f200 => $MODE;

      LDR input => $A;

      LDR output => $B;/* get the output pointer */

      ADDR #-64,[$A]; /* offset the registers to use pre_increment addr */

      ADDR #-32,[$B]; /* offset the registers to use pre_increment addr */

      LDR #4 => $LC;

MAG_LOOP_512::

      LD_C:(32) $A+=64 => $C0;  /* get the first segment */

      MAG_C:(32,ACCURACY) $C0  ;  /* convert the segment in memory */

      LD_C:(32) $A+=64 => $C1; /* get next segment */

      MAG_C:(32,ACCURACY) $C1 ;  /* convert the segment in memory */

      ST_R:(32) $R0 => $B+=32; /* store the first segment */

      ST_R:(32) $R1 => $B+=32; /* store the second segment */

      LD_C:(32) $A+=64 => $C0;  /* get the third segment */

      MAG_C:(32,ACCURACY) $C0  ;  /* convert the segment in memory */

      LD_C:(32) $A+=64 => $C1; /* get fourth segment */

      MAG_C:(32,ACCURACY) $C1 ;  /* convert the segment in memory */

      ST_R:(32) $R0 => $B+=32; /* store the third segment */

      ST_R:(32) $R1 => $B+=32; /* store the fourth segment */

      JMPC:[DL] [!LZ], MAG_LOOP_512;

   }

   SUBROUTINE MAG_1024(zr325ref input,zr325ref output)

   {

          

      LDR #0x50f200 => $MODE;

      LDR input => $A;

      LDR output => $B;/* get the output pointer */

      ADDR #-64,[$A]; /* offset the registers to use pre_increment addr */

      ADDR #-32,[$B]; /* offset the registers to use pre_increment addr */

      LDR #8 => $LC;

   MAG_LOOP_1024::

      LD_C:(32) $A+=64 => $C0;  /* get the first segment */

      MAG_C:(32,ACCURACY) $C0  ;  /* convert the segment in memory */

      LD_C:(32) $A+=64 => $C1; /* get next segment */

      MAG_C:(32,ACCURACY) $C1 ;  /* convert the segment in memory */

      ST_R:(32) $R0 => $B+=32; /* store the first segment */

      ST_R:(32) $R1 => $B+=32; /* store the second segment */

      LD_C:(32) $A+=64 => $C0;  /* get the third segment */

      MAG_C:(32,ACCURACY) $C0  ;  /* convert the segment in memory */

      LD_C:(32) $A+=64 => $C1; /* get fourth segment */

      MAG_C:(32,ACCURACY) $C1 ;  /* convert the segment in memory */

      ST_R:(32) $R0 => $B+=32; /* store the third segment */

      ST_R:(32) $R1 => $B+=32; /* store the fourth segment */

      JMPC:[DL] [!LZ], MAG_LOOP_1024;

   }

   

#/

}

