

/**************************************************************/

/* Max       Routine                                          */

/* Description: Takes an input vectors and locates a spec'd   */

/* number of peaks.  The peaks are stored in a buffer as:     */

/* Peak Center Index(PCI), in[PCI-1],in[PCI],in[PCI+1]        */

/* After each peak is located, it is zeroed out in the input  */

/* Note that the input array is damaged after finding peaks   */

/**************************************************************/

zsp325()

{

/#

.ORG 0x01A000;

.DATA In_Data 1024;

.ORG 0x01B000;

.DATA Out_Data 256;

.DATA In_Ptr  {&In_Data};

.DATA Out_Ptr  {&Out_Data};

.ORG 0x010000 ;

   SUBROUTINE MAX_8(zr325ref in,zr325ref out,zr325val num_peaks)

   {

          

      LDR #0x50f201 => $MODE;

      LDR num_peaks => $LC;  /* set up the loop counter */

      LDR out => $A;/* get the output pointer */

      ADDR $A,#-1; /* compensate for pre-autoincrement addressing */

      LD_R:(1) $A => $R0; /* zero internal mem */

      MAX8LOOP::

          LDR in => $B;

          MAX:(2,4) $B => $MNMX; /* find max */

          STR $MNMXI => $A+=1; /* store index */

          ADDR $B, $A => $X ;

          ADDR $B,#-1; /* sub 1 to get a region of 3 */

          /* use these instructions if you need to xfer the values */

          /* LD_R:(3) $B => $R0; */ /* get the region, zero other internal mem */

          /* ST_R:(3) $R0 => $A+=1; */ /* store the region, inc pointer */

          ST_R:(3) $R0+4 => $B; /* and zero out the region */

          STR $MNMXV => $A+=1; /* store peak magnitude */

          JMPC:[DL] [!LZ], MAX8LOOP;

   }

   SUBROUTINE MAX_16(zr325ref in,zr325ref out,zr325val num_peaks)

   {

          

      LDR #0x50f201 => $MODE;

      LDR num_peaks => $LC;  /* set up the loop counter */

      LDR out => $A;/* get the output pointer */

      ADDR $A,#-1; /* compensate for pre-autoincrement addressing */

      LD_R:(1) $A => $R0; /* zero internal mem */

      MAX16LOOP::

          LDR in => $B;

          MAX:(4,4) $B => $MNMX; /* find max */

          STR $MNMXI => $A+=1; /* store index */

          ADDR $B, $A => $X ;

          ADDR $B,#-1; /* sub 1 to get a region of 3 */

          /* use these instructions if you need to xfer the values */

          /* LD_R:(3) $B => $R0; */ /* get the region, zero other internal mem */

          /* ST_R:(3) $R0 => $A+=1; */ /* store the region, inc pointer */

          ST_R:(3) $R0+4 => $B; /* and zero out the region */

          STR $MNMXV => $A+=1; /* store peak magnitude */

          JMPC:[DL] [!LZ], MAX16LOOP;

   }

   SUBROUTINE MAX_32(zr325ref in,zr325ref out,zr325val num_peaks)

   {

          

      LDR #0x50f201 => $MODE;

      LDR num_peaks => $LC;  /* set up the loop counter */

      LDR out => $A;/* get the output pointer */

      ADDR $A,#-1; /* compensate for pre-autoincrement addressing */

      LD_R:(1) $A => $R0; /* zero internal mem */

      MAX32LOOP::

          LDR in => $B;

          MAX:(4,8) $B => $MNMX; /* find max */

          STR $MNMXI => $A+=1; /* store index */

          ADDR $B, $A => $X ;

          ADDR $B,#-1; /* sub 1 to get a region of 3 */

          /* use these instructions if you need to xfer the values */

          /* LD_R:(3) $B => $R0; */ /* get the region, zero other internal mem */

          /* ST_R:(3) $R0 => $A+=1; */ /* store the region, inc pointer */

          ST_R:(3) $R0+4 => $B; /* and zero out the region */

          STR $MNMXV => $A+=1; /* store peak magnitude */

          JMPC:[DL] [!LZ], MAX32LOOP;

   }

   SUBROUTINE MAX_64(zr325ref in,zr325ref out,zr325val num_peaks)

   {

          

      LDR #0x50f201 => $MODE;

      LDR num_peaks => $LC;  /* set up the loop counter */

      LDR out => $A;/* get the output pointer */

      ADDR $A,#-1; /* compensate for pre-autoincrement addressing */

      LD_R:(1) $A => $R0; /* zero internal mem */

      MAX64LOOP::

          LDR in => $B;

          MAX:(2,32) $B => $MNMX; /* find max */

          STR $MNMXI => $A+=1; /* store index */

          ADDR $B, $A => $X ;

          ADDR $B,#-1; /* sub 1 to get a region of 3 */

          /* use these instructions if you need to xfer the values */

          /* LD_R:(3) $B => $R0; */ /* get the region, zero other internal mem */

          /* ST_R:(3) $R0 => $A+=1; */ /* store the region, inc pointer */

          ST_R:(3) $R0+4 => $B; /* and zero out the region */

          STR $MNMXV => $A+=1; /* store peak magnitude */

          JMPC:[DL] [!LZ], MAX64LOOP;

   }

   SUBROUTINE MAX_128(zr325ref in,zr325ref out,zr325val num_peaks)

   {

          

      LDR #0x50f201 => $MODE;

      LDR num_peaks => $LC;  /* set up the loop counter */

      LDR out => $A;/* get the output pointer */

      ADDR $A,#-1; /* compensate for pre-autoincrement addressing */

      LD_R:(1) $A => $R0; /* zero internal mem */

      MAX128LOOP::

          LDR in => $B;

          MAX:(4,32) $B => $MNMX; /* find max */

          STR $MNMXI => $A+=1; /* store index */

          ADDR $B, $A => $X ;

          ADDR $B,#-1; /* sub 1 to get a region of 3 */

          /* use these instructions if you need to xfer the values */

          /* LD_R:(3) $B => $R0; */ /* get the region, zero other internal mem */

          /* ST_R:(3) $R0 => $A+=1; */ /* store the region, inc pointer */

          ST_R:(3) $R0+4 => $B; /* and zero out the region */

          STR $MNMXV => $A+=1; /* store peak magnitude */

          JMPC:[DL] [!LZ], MAX128LOOP;

   }

   SUBROUTINE MAX_256(zr325ref in,zr325ref out,zr325val num_peaks)

   {

          

      LDR #0x50f201 => $MODE;

      LDR num_peaks => $LC;  /* set up the loop counter */

      LDR out => $A;/* get the output pointer */

      ADDR $A,#-1; /* compensate for pre-autoincrement addressing */

      LD_R:(1) $A => $R0; /* zero internal mem */

      MAX256LOOP::

          LDR in => $B;

          MAX:(8,32) $B => $MNMX; /* find max */

          STR $MNMXI => $A+=1; /* store index */

          ADDR $B, $A => $X ;

          ADDR $B,#-1; /* sub 1 to get a region of 3 */

          /* use these instructions if you need to xfer the values */

          /* LD_R:(3) $B => $R0; */ /* get the region, zero other internal mem */

          /* ST_R:(3) $R0 => $A+=1; */ /* store the region, inc pointer */

          ST_R:(3) $R0+4 => $B; /* and zero out the region */

          STR $MNMXV => $A+=1; /* store peak magnitude */

          JMPC:[DL] [!LZ], MAX256LOOP;

   }

   SUBROUTINE MAX_512(zr325ref in,zr325ref out,zr325val num_peaks)

   {

          

      LDR #0x50f201 => $MODE;

      LDR num_peaks => $LC;  /* set up the loop counter */

      LDR out => $A;/* get the output pointer */

      ADDR $A,#-1; /* compensate for pre-autoincrement addressing */

      LD_R:(1) $A => $R0; /* zero internal mem */

      MAX512LOOP::

          LDR in => $B;

          MAX:(4,128) $B => $MNMX; /* find max */

          STR $MNMXI => $A+=1; /* store index */

          ADDR $B, $A => $X ;

          ADDR $B,#-1; /* sub 1 to get a region of 3 */

          /* use these instructions if you need to xfer the values */

          /* LD_R:(3) $B => $R0; */ /* get the region, zero other internal mem */

          /* ST_R:(3) $R0 => $A+=1; */ /* store the region, inc pointer */

          ST_R:(3) $R0+4 => $B; /* and zero out the region */

          STR $MNMXV => $A+=1; /* store peak magnitude */

          JMPC:[DL] [!LZ], MAX512LOOP;

   }



SUBROUTINE MAIN() {



   CALL MAX_512(&In_Data,&Out_Data,10);

} 



#/

}

