

/**************************************************************/

/* Int_to_FP_Wind Routine                                     */

/* Description: Takes an input vectors and converts from a    */

/* 16 bit twos-complement representation to an IEEE floating  */

/* point number (32 bit)                                      */

/* The resultant 32 bit float is then multiplied by the window */

/* function and stored in place                                */

/**************************************************************/

zsp325()

{

/#

   SUBROUTINE INT_TO_FLOAT_WIND_8(zr325ref input, zr325ref window)

   {



      LDR #0x50f200 => $MODE;

      LDR input => $A;

      LDR window => $B;/* get the output pointer */

      LD_R:(8) $A => $R0;  /* get the first segment */

      INTFP_R:(8) $R0 => $R0 ;  /* convert the segment in memory */

      LD_I:(8) $B:(1,1) => $I0;

      MULT_R:(8) $I0, $R0 => $R0 ;

      ST_R:(8) $R0 => $A; /* store the first segment */

   }

   SUBROUTINE INT_TO_FLOAT_WIND_16(zr325ref input, zr325ref window)

   {



      LDR #0x50f200 => $MODE;

      LDR input => $A;

      LDR window => $B;/* get the output pointer */

      LD_R:(16) $A => $R0;  /* get the first segment */

      INTFP_R:(16) $R0 => $R0 ;  /* convert the segment in memory */

      LD_I:(16) $B:(1,1) => $I0;

      MULT_R:(16) $I0, $R0 => $R0 ;

      ST_R:(16) $R0 => $A; /* store the first segment */

   }

   SUBROUTINE INT_TO_FLOAT_WIND_32(zr325ref input, zr325ref window)

   {



      LDR #0x50f200 => $MODE;

      LDR input => $A;

      LDR window => $B;/* get the output pointer */

      LD_R:(32) $A => $R0;  /* get the first segment */

      INTFP_R:(32) $R0 => $R0 ;  /* convert the segment in memory */

      LD_I:(32) $B:(1,1) => $I0;

      MULT_R:(32) $I0, $R0 => $R0 ;

      ST_R:(32) $R0 => $A; /* store the first segment */

   }

   SUBROUTINE INT_TO_FLOAT_WIND_64(zr325ref input, zr325ref window)

   {

      LDR #0x50f211 => $MODE;

      LDR input => $A;

      LDR window => $B;/* get the output pointer */

      LD_R:(64) $A => $R;  /* get the first segment */

      LD_I:(64) $B:(1,1) => $I ; /* get the window function */

      INTFP_R:(64) $R => $R ;  /* convert the segment in memory */

      MULT_R:(64) $I, $R => $R ;

      ST_R:(64) $R => $A; /* store the first segment */

   }

   SUBROUTINE INT_TO_FLOAT_WIND_128(zr325ref input, zr325ref window)

   {

      LDR #0x50f211 => $MODE;

      LDR input => $A;

      LDR window => $B;/* get the output pointer */

      LDR #2 => $LC;  /* loop twice */

INTFPW_LOOP_128::

      LD_R:(64) $A => $R;  /* get the first segment */

      LD_I:(64) $B:(1,1) => $I ; /* get the window function */

      INTFP_R:(64) $R => $R ;  /* convert the segment in memory */

      MULT_R:(64) $I, $R => $R ;

      ST_R:(64) $R => $A; /* store the first segment */

      ADDR  #64,[$A,$B];  /* increment the pointer registers */

      JMPC:[DL] [!LZ], INTFPW_LOOP_128;

   }

   SUBROUTINE INT_TO_FLOAT_WIND_256(zr325ref input, zr325ref window)

   {

      LDR #0x50f211 => $MODE;

      LDR input => $A;

      LDR window => $B;/* get the output pointer */

      LDR #4 => $LC;  /* loop 4 times */

INTFPW_LOOP_256::

      LD_R:(64) $A => $R;  /* get the first segment */

      LD_I:(64) $B:(1,1) => $I ; /* get the window function */

      INTFP_R:(64) $R => $R ;  /* convert the segment in memory */

      MULT_R:(64) $I, $R => $R ;

      ST_R:(64) $R => $A; /* store the first segment */

      ADDR  #64,[$A,$B];  /* increment the pointer registers */

      JMPC:[DL] [!LZ], INTFPW_LOOP_256;

   }

   SUBROUTINE INT_TO_FLOAT_WIND_512(zr325ref input, zr325ref window)

   {

      LDR #0x50f211 => $MODE;

      LDR input => $A;

      LDR window => $B;/* get the output pointer */

      LDR #8 => $LC;  /* loop twice */

INTFPW_LOOP_512::

      LD_R:(64) $A => $R;  /* get the first segment */

      LD_I:(64) $B:(1,1) => $I ; /* get the window function */

      INTFP_R:(64) $R => $R ;  /* convert the segment in memory */

      MULT_R:(64) $I, $R => $R ;

      ST_R:(64) $R => $A; /* store the first segment */

      ADDR  #64,[$A,$B];  /* increment the pointer registers */

      JMPC:[DL] [!LZ], INTFPW_LOOP_512;

   }

   SUBROUTINE INT_TO_FLOAT_WIND_1024(zr325ref input, zr325ref window)

   {

      LDR #0x50f211 => $MODE;

      LDR input => $A;

      LDR window => $B;/* get the output pointer */

      LDR #16 => $LC;  /* loop twice */

INTFPW_LOOP_1024::

      LD_R:(64) $A => $R;  /* get the first segment */

      LD_I:(64) $B:(1,1) => $I ; /* get the window function */

      INTFP_R:(64) $R => $R ;  /* convert the segment in memory */

      MULT_R:(64) $I, $R => $R ;

      ST_R:(64) $R => $A; /* store the first segment */

      ADDR  #64,[$A,$B];  /* increment the pointer registers */

      JMPC:[DL] [!LZ], INTFPW_LOOP_1024;

   }



#/

}

